@@ -39,6 +39,7 @@ from ._identity_protection import _identity_protection_endpoints
 from ._installation_tokens import _installation_tokens_endpoints
 from ._ioc import _ioc_endpoints
 from ._iocs import _iocs_endpoints
+from ._ods import _ods_endpoints
 from ._real_time_response import _real_time_response_endpoints
 from ._real_time_response_admin import _real_time_response_admin_endpoints
 from ._report_executions import _report_executions_endpoints
@@ -52,6 +53,7 @@ _identity_protection_deprecated = _identity_protection_endpoints
 _installation_tokens_deprecated = _installation_tokens_endpoints
 _ioc_deprecated = _ioc_endpoints
 _iocs_deprecated = _iocs_endpoints
+_ods_deprecated = _ods_endpoints
 _real_time_response_deprecated = _real_time_response_endpoints
 _real_time_response_admin_deprecated = _real_time_response_admin_endpoints
 _report_executions_deprecated = _report_executions_endpoints
