@@ -37,6 +37,32 @@ For more information, please refer to <https://unlicense.org>
 """
 
 _ioc_endpoints = [
+  [
+    "indicator.aggregate.v1",
+    "POST",
+    "/iocs/aggregates/indicators/v1",
+    "Get Indicators aggregates as specified via json in the request body.",
+    "ioc",
+    [
+      {
+        "type": "string",
+        "description": "The filter to narrow down the aggregation data",
+        "name": "filter",
+        "in": "query"
+      },
+      {
+        "type": "boolean",
+        "description": "The filter for returning either only indicators for the request customer or its MSSP parents",
+        "name": "from_parent",
+        "in": "query"
+      },
+      {
+        "name": "body",
+        "in": "body",
+        "required": True
+      }
+    ]
+  ],
   [
     "indicator.combined.v1",
     "GET",
@@ -88,6 +114,40 @@ _ioc_endpoints = [
         "description": "The sort expression that should be used to sort the results.",
         "name": "sort",
         "in": "query"
+      },
+      {
+        "type": "string",
+        "description": "A pagination token used with the `limit` parameter to manage pagination of results. "
+        "On your first request, don't provide an 'after' token. On subsequent requests, provide the 'after' "
+        "token from the previous response to continue from that place in the results. "
+        "To access more than 10k indicators, use the 'after' parameter instead of 'offset'.",
+        "name": "after",
+        "in": "query"
+      },
+      {
+        "type": "boolean",
+        "description": "The filter for returning either only indicators for the request customer or its MSSP parents",
+        "name": "from_parent",
+        "in": "query"
+      }
+    ]
+  ],
+  [
+    "action.get.v1",
+    "GET",
+    "/iocs/entities/actions/v1",
+    "Get Actions by ids.",
+    "ioc",
+    [
+      {
+        "type": "array",
+        "items": {
+          "type": "string"
+        },
+        "collectionFormat": "csv",
+        "description": "The ids of the Actions to retrieve",
+        "name": "ids",
+        "in": "query"
       }
     ]
   ],
@@ -119,19 +179,13 @@ _ioc_endpoints = [
     "ioc",
     [
       {
-        "type": "string",
-        "description": "The username",
-        "name": "X-CS-USERNAME",
-        "in": "header"
-      },
-      {
-        "type": "bool",
+        "type": "boolean",
         "description": "Whether to submit to retrodetects",
         "name": "retrodetects",
         "in": "query"
       },
       {
-        "type": "bool",
+        "type": "boolean",
         "default": False,
         "description": "Set to true to ignore warnings and add all IOCs",
         "name": "ignore_warnings",
@@ -152,19 +206,13 @@ _ioc_endpoints = [
     "ioc",
     [
       {
-        "type": "string",
-        "description": "The username",
-        "name": "X-CS-USERNAME",
-        "in": "header"
-      },
-      {
-        "type": "bool",
+        "type": "boolean",
         "description": "Whether to submit to retrodetects",
         "name": "retrodetects",
         "in": "query"
       },
       {
-        "type": "bool",
+        "type": "boolean",
         "default": False,
         "description": "Set to true to ignore warnings and add all IOCs",
         "name": "ignore_warnings",
@@ -207,6 +255,33 @@ _ioc_endpoints = [
         "description": "The comment why these indicators were deleted",
         "name": "comment",
         "in": "query"
+      },
+      {
+        "type": "boolean",
+        "description": "The filter for returning either only indicators for the request customer or its MSSP parents",
+        "name": "from_parent",
+        "in": "query"
+      }
+    ]
+  ],
+  [
+    "action.query.v1",
+    "GET",
+    "/iocs/queries/actions/v1",
+    "Query Actions.",
+    "ioc",
+    [
+      {
+        "type": "string",
+        "description": "Starting index of overall result set from which to return ids.",
+        "name": "offset",
+        "in": "query"
+      },
+      {
+        "type": "integer",
+        "description": "Number of ids to return.",
+        "name": "limit",
+        "in": "query"
       }
     ]
   ],
@@ -261,6 +336,78 @@ _ioc_endpoints = [
         "description": "The sort expression that should be used to sort the results.",
         "name": "sort",
         "in": "query"
+      },
+      {
+        "type": "string",
+        "description": "A pagination token used with the `limit` parameter to manage pagination of results. "
+        "On your first request, don't provide an 'after' token. On subsequent requests, provide the 'after' "
+        "token from the previous response to continue from that place in the results. "
+        "To access more than 10k indicators, use the 'after' parameter instead of 'offset'.",
+        "name": "after",
+        "in": "query"
+      }
+    ]
+  ],
+  [
+    "ioc_type.query.v1",
+    "GET",
+    "/iocs/queries/ioc-types/v1",
+    "Query IOC Types.",
+    "ioc",
+    [
+      {
+        "type": "string",
+        "description": "Starting index of overall result set from which to return ids.",
+        "name": "offset",
+        "in": "query"
+      },
+      {
+        "type": "integer",
+        "description": "Number of ids to return.",
+        "name": "limit",
+        "in": "query"
+      }
+    ]
+  ],
+  [
+    "platform.query.v1",
+    "GET",
+    "/iocs/queries/platforms/v1",
+    "Query Platforms.",
+    "ioc",
+    [
+      {
+        "type": "string",
+        "description": "Starting index of overall result set from which to return ids.",
+        "name": "offset",
+        "in": "query"
+      },
+      {
+        "type": "integer",
+        "description": "Number of ids to return.",
+        "name": "limit",
+        "in": "query"
+      }
+    ]
+  ],
+  [
+    "severity.query.v1",
+    "GET",
+    "/iocs/queries/severities/v1",
+    "Query Severities.",
+    "ioc",
+    [
+      {
+        "type": "string",
+        "description": "Starting index of overall result set from which to return ids.",
+        "name": "offset",
+        "in": "query"
+      },
+      {
+        "type": "integer",
+        "description": "Number of ids to return.",
+        "name": "limit",
+        "in": "query"
       }
     ]
   ]
